#
# Introduction to GIS using R
# by Cole White and Nadia Muhe, 2024
#=================================================================

  
# Set Working Directory
setwd("Enter Path to the RGISfiles Folder")

# Install and Load Packages
install.packages(c("sf", "ggplot2", "ggspatial", "RColorBrewer"))
library(sf)
library(ggplot2)
library(ggspatial)
library(RColorBrewer)



# 1. Point Features
# Creating data using longitude/latitude pairs and names of places
longitude <- c(-79.4094, -79.3946, -79.3322, -79.5169)
latitude <- c(43.6781, 43.6677, 43.7253, 43.7735)
names <- c('Casa Loma', 'Royal Ontario Museum', 'Aga Khan Museum',
           'Black Creek Pioneer Village')

# Convert list to dataframe
museums <- data.frame(longitude, latitude, names)
museums

# Convert dataframe to sf object
museums_sf <- st_as_sf(museums, coords=c("longitude", "latitude"),
                      crs="EPSG:4326")
museums_sf

# Map museums using ggplot2
ggplot() + geom_sf(data=museums_sf)



# 2. Line Features
# Import data
subway_lines_sf <- read_sf('TTC_SUBWAY_LINES_WGS84.shp')
subway_lines_sf

# Map subway lines
ggplot() + geom_sf(data=subway_lines_sf)

# Additional data for subway lines: subway stations
# Import CSV file & convert dataframe to sf object
subway_stations <- read.csv('subway_stations.csv')
subway_stations_sf <- st_as_sf(subway_stations, coords=c('lon', 'lat'), crs=4326)

# Map subway lines with subway stations
ggplot() + geom_sf(data=subway_lines_sf) +
  geom_sf(data=subway_stations_sf)



# 3. Polygon Features
# Import Toronto neighbourhoods
neighbourhoods_sf <- read_sf('Neighbourhoods - 4326.shp')
neighbourhoods_sf

# Map Toronto neighbourhoods
ggplot() + geom_sf(data=neighbourhoods_sf)

# Additional data for Toronto neighbourhoods: Cultural Hot Spots (point features)
culturalhotspots_sf <- read_sf('points-of-interest - 4326.shp')
culturalhotspots_sf



# 4. Mapping using ggplot2 
# Mapping multiple spatial data layers
ggplot() + 
  geom_sf(data=neighbourhoods_sf) + 
  geom_sf(data=subway_lines_sf) + 
  geom_sf(data=subway_stations_sf) +
  geom_sf(data=museums_sf)

# Polygon features: to modify colours within the polygon and the border
ggplot() + 
  geom_sf(data=neighbourhoods_sf, colour="darkgrey", fill="#354f52") +
  geom_sf(data=subway_lines_sf) + 
  geom_sf(data=subway_stations_sf) +
  geom_sf(data=museums_sf)

# Line features: to modify the colour and line width
ggplot() + 
  geom_sf(data=neighbourhoods_sf, colour="darkgrey", fill="#354f52") +
  geom_sf(data=subway_lines_sf, colour="lightgrey", linewidth=1) + 
  geom_sf(data=subway_stations_sf) +
  geom_sf(data=museums_sf)

# Point features: to modify the colour, size, and shape 
ggplot() + 
  geom_sf(data=neighbourhoods_sf, colour="darkgrey", fill="#354f52") +
  geom_sf(data=subway_lines_sf, colour="lightgrey", linewidth=1) + 
  geom_sf(data=subway_stations_sf, colour="lightgrey", size=1.5) +
  geom_sf(data=museums_sf, colour="maroon2", size=3, shape=17)

# To apply a theme to the map
ggplot() + 
  geom_sf(data=neighbourhoods_sf, colour="darkgrey", fill="#354f52") +
  geom_sf(data=subway_lines_sf, colour="lightgrey", linewidth=1) + 
  geom_sf(data=subway_stations_sf, colour="lightgrey", size=1.5) +
  geom_sf(data=museums_sf, colour="maroon2", size=3, shape=17) + 
  theme_classic()

# To add a title
ggplot() + 
  geom_sf(data=neighbourhoods_sf, colour="darkgrey", fill="#354f52") +
  geom_sf(data=subway_lines_sf, colour="lightgrey", linewidth=1) + 
  geom_sf(data=subway_stations_sf, colour="lightgrey", size=1.5) +
  geom_sf(data=museums_sf, colour="maroon2", size=3, shape=17) + 
  theme_classic() +
  ggtitle("Museums and Subway Lines",
          subtitle="Toronto, Canada")

# To add a scale bar (package: ggspatial)
ggplot() + 
  geom_sf(data=neighbourhoods_sf, colour="darkgrey", fill="#354f52") +
  geom_sf(data=subway_lines_sf, colour="lightgrey", linewidth=1) + 
  geom_sf(data=subway_stations_sf, colour="lightgrey", size=1.5) +
  geom_sf(data=museums_sf, colour="maroon2", size=3, shape=17) + 
  theme_classic() +
  ggtitle("Museums and Subway Lines",
          subtitle="Toronto, Canada") +
  annotation_scale(location = "br", bar_cols = c("grey20", "white"))

# To add the north arrow (package: ggspatial)
ggplot() + 
  geom_sf(data=neighbourhoods_sf, colour="darkgrey", fill="#354f52") +
  geom_sf(data=subway_lines_sf, colour="lightgrey", linewidth=1) + 
  geom_sf(data=subway_stations_sf, colour="lightgrey", size=1.5) +
  geom_sf(data=museums_sf, colour="maroon2", size=3, shape=17) + 
  theme_classic() +
  ggtitle("Museums and Subway Lines",
          subtitle="Toronto, Canada") +
  annotation_scale(location = "br", bar_cols = c("grey20", "white")) +
  annotation_north_arrow(location = "br", which_north = "true",
                         pad_x = unit(0.1, "in"), pad_y = unit(0.3, "in"),
                         style = north_arrow_nautical(fill = c("grey40", "white"), 
                                                      line_col = "grey20"))




# 5. Spatial Analysis

## 5.1 Length of Features
# Length of subway lines
st_length(subway_lines_sf)

# Store length as a new variable
subway_lines_sf$length_metres <-st_length(subway_lines_sf)
subway_lines_sf


## 5.2 Distance Between Features: Points vs Lines
# Distance between museums and subway lines
st_distance(museums_sf, subway_lines_sf)

# Store values in data frame
dist_table <- data.frame(st_distance(museums_sf, subway_lines_sf))

# Assign names to rows and columns
colnames(dist_table) <- subway_lines_sf$ROUTE_NAME
rownames(dist_table) <- museums_sf$names
dist_table


## 5.3 Distance Between Features: Points vs Points
# Distance between museums and subway stations
st_distance(museums_sf, subway_stations_sf)


## 5.4 Nearest Feature
# Find the nearest subway station index for each museum
st_nearest_feature(museums_sf, subway_stations_sf)

# Use index to identify subway station name
subway_stations_sf$Name[st_nearest_feature(museums_sf, subway_stations_sf)]

# Save list of nearest stations as a new field
museums_sf$nearest_subway_station <- subway_stations_sf$Name[st_nearest_feature(museums_sf, subway_stations_sf)]
museums_sf




## 5.5 Number of points in polygon
# Number of cultural hot spots in each neighbourhood
lengths(st_intersects(neighbourhoods_sf, culturalhotspots_sf))

# Store number as a new variable
neighbourhoods_sf$counthotspots <- lengths(st_intersects(neighbourhoods_sf, culturalhotspots_sf))




# 6. Choropleth Map using ggplot2

# Example 1: Basic choropleth using default colours
ggplot() + 
  geom_sf(data=neighbourhoods_sf, aes(fill=counthotspots)) + 
  scale_fill_gradient(low="white", high="darkgreen")

# Example 1: Complete choropleth using default colours
ggplot() + 
  geom_sf(data=neighbourhoods_sf, aes(fill=counthotspots)) + 
  scale_fill_gradient(low="white", high="darkgreen") +
  theme_classic() +
  labs(fill="Number of\nCultural Hot\nSpots") +
  annotation_scale(location = "br", bar_cols = c("grey20", "white")) +
  annotation_north_arrow(location = "br", which_north = "true",
                         pad_x = unit(0.1, "in"), pad_y = unit(0.3, "in"),
                         style = north_arrow_nautical(fill = c("grey40", "white"), 
                                                      line_col = "grey20"))


# Example 2: Basic choropleth using the ColorBrewer palette
ggplot() + 
  geom_sf(data=neighbourhoods_sf, aes(fill=counthotspots)) + 
  scale_fill_distiller(palette="Greens", direction=1)


# Example 2: Complete choropleth using the ColorBrewer palette
ggplot() + 
  geom_sf(data=neighbourhoods_sf, aes(fill=counthotspots)) + 
  scale_fill_distiller(palette="Greens", direction=1) +
  theme_classic() +
  labs(fill="Number of\nCultural Hot\nSpots") +
  annotation_scale(location = "br", bar_cols = c("grey20", "white")) +
  annotation_north_arrow(location = "br", which_north = "true",
                         pad_x = unit(0.1, "in"), pad_y = unit(0.3, "in"),
                         style = north_arrow_fancy_orienteering(fill = c("grey40", "white"), 
                                                      line_col = "grey20"))

